# Example: Read single electron sample and plot pseudorapidity   
# It fills 2 Python lists with particles and reco electrons
# S.Chekanov (ANL)

import glob
from org.lcsim.lcio import LCIOReader
from hep.io.sio import SIOReader
from hep.lcio.implementation.sio import SIOLCReader
from hep.lcio.implementation.io import LCFactory
from hep.lcio.event import * 
from hep.lcio.io import *
from jhplot import *  # import graphics
from hephysics.particle import LParticle
from java.awt import Color
from java.lang import System

# make list of files..
files=glob.glob("pgun_elec_eta45_30gev%rfull051/*.slcio")
factory = LCFactory.getInstance()
nEvent=0
h1=H1D("True Eta",20,-4,4)
h2=H1D("Reco Eta",20,-4,4)

h3=H1D("True Eta pT>4 GeV",20,-4,4)
h4=H1D("Reco Eta pT>4 GeV",20,-4,4)


nfile=0
for f in files:
  print "Open file=",f
  reader = factory.createLCReader()
  reader.open(f) 
  nfile=nfile+1
  while(1):
    evt=reader.readNextEvent()
    if (evt == None): break
    nEvent=nEvent+1
    # print " file event: ",evt.getEventNumber(), " run=",evt.getRunNumber()
    if (nEvent%100==0): print "# Event: ",nEvent

    # truth-level particles
    col = evt.getCollection("MCParticle")
    nMc=col.getNumberOfElements()
    particles=[]
    for i in range(nMc): # loop over all particles 
       par=col.getElementAt(i)
       if(par.getGeneratorStatus() == 1 and par.getCharge() !=0): 
              vertex = par.getVertex();
              pdg=par.getPDG()
              momentum = par.getMomentum() 
              ee=par.getEnergy()
              mass=par.getMass()
              px=momentum[0]
              py=momentum[1]
              pz=momentum[2]
              charge=par.getCharge()
              # http://jwork.org/dmelt/api/doc.php/hephysics/particle/LParticle
              p=LParticle(px,py,pz,ee,mass) 
              p.setCharge(charge)
              if (abs(pdg)==11): 
                           if (p.perp()>0.5): h1.fill(p.pseudoRapidity())
                           if (p.perp()>4):   h3.fill(p.pseudoRapidity())
                           particles.append(p) # list with electrons 
              #print nn, "pdg=",pdg, " ",px,py,pz, " charge=",charge 

    # look at reconstruced electrons
    col = evt.getCollection("PandoraPFOCollection")
    nPFA = col.getNumberOfElements()
    electrons=[]
    for i in range(nPFA):
          # http://www.lcsim.org/sites/lcsim/apidocs/org/lcsim/lcio/SIOReconstructedParticle.html
          # http://www.lcsim.org/sites/lcsim/apidocs/org/lcsim/event/ReconstructedParticle.html
          pa=col.getElementAt(i)
          charge=pa.getCharge()
          p4=pa.getMomentum()
          ee=pa.getEnergy()
          ptype=pa.getType() # type
          p=LParticle(p4[0],p4[1],p4[2],ee)
          p.setCharge(charge)
          if (abs(ptype)==11 and p.perp()>1): # 1 gev electron with min pT=1 
                               if (p.perp()>0.5): h2.fill(p.pseudoRapidity())
                               if (p.perp()>4):   h4.fill(p.pseudoRapidity())
                               electrons.append(p) # list with reconstructed electrons 

    del col
    del evt

  reader.close() # close the file
  del reader
  if (nfile%5==0): System.gc() # if you low on memory, manual JVM cleanup for every 5th file 


print "Plot 2 histograms.."
c1=HPlot("Electrons",500,700,1,2)
c1.visible()
c1.setAutoRange()
c1.setMarginLeft(100)
c1.setNameX("&eta;")
c1.setNameY("Entries")
c1.setRangeX(-4.5,4.5)
# c1.setRangeY(0,10000)
c1.draw(h1)
l1=HLabel("pT>0.5 GeV", 0.7, 0.85, "NDC")
c1.add(l1)
p1=P1D(h2) # draw reconstructed as symbols 
p1.setColor(Color.blue)
c1.draw(p1)

c1.cd(1,2) # second pad 
c1.setAutoRange()
c1.setMarginLeft(100)
c1.setNameX("&eta;")
c1.setNameY("Entries")
c1.setRangeX(-4.5,4.5)
# c1.setRangeY(0,10000)


c1.draw(h3)
l1=HLabel("pT>4 GeV", 0.7, 0.85, "NDC")
c1.add(l1)
p1=P1D(h4)
p1.setColor(Color.blue)
c1.draw(p1)


c1.export("mc_electrons.pdf")

